################################################################################
#
# File:         USMarc.py
# RCS:          $Id: USMarc.py,v 1.2 2007/07/30 05:35:02 paepcke Exp $
# Description:  US Marc fieldnames
# Author:       Andreas Paepcke, Stanford University
# Created:      Wed Oct 11 11:26:30 1995
# Modified:     Sun Jul 29 14:44:36 2007 (Andreas Paepcke) paepcke@EMIL
# Language:     Python
# Package:      N/A
# Status:       Experimental (Do Not Distribute)
#
# (c) Copyright 1995, Stanford University, all rights reserved.
#
################################################################################
#
# Revisions:
#
# Sun Jul 29 14:44:04 2007 (Andreas Paepcke) paepcke@EMIL
#  changed calls to method convert() into convertAttr()
# Thu Nov  7 14:58:52 1996 (Andreas Paepcke) paepcke@Stingray
#  Added kVaryingTitle and kSeries.
################################################################################

## locally defined USMarc codes.

## Added by AC
kMovieURL = '941'
kFilmStripURL = '942'
kTranscriptURL = '943'
## End of addition

kContent = '945'
kContentLength = '946'
kContentType = '590'     ## conference paper, technical report, etc.
kContentTypeNote = '525'  ## what is included in the content (like an abstract, illustrations, etc.) 

kWeight = '960'
kURL = '856'
kOrdering = '961'   ## absolute ordering
kAdvertisement = '962'  

kCopyright = '996'
kCountry = '997'
kAbbreviatedPublication = '998'
kLanguage = '999'

## standard USMarc codes.

kISBN = '020'
kISSN = '022'


kPublicationDate = '523'
kPublicationYear = '046'

kMainEntryUniformTitle = '130'
kTitleStatement = '245'
kUniformTitle = '240'
kTitle = kTitleStatement
kVaryingTitle = '246'

kMainEntryPersonalName = '100'
kAuthor = kMainEntryPersonalName

kAbstract = '520'

kGeneralNote = '500'
kBibliographicNote = '504'


kPublication = '260a'
kPublisher = '260b' 
kIssuingOrganization = '710' 


kEdition = '250'
kVolume = '250v'
kNumber = '250n'
kSeries = '440'
kPhysicalDescription = '300'
kPageNumber = '942zztop'

kSubjectPersonalName = '600'
kSubjectCorporateName = '610'
kSubjectTopicalTerm = '650'
kSubjectGeographicName = '651'

kConferenceTitle = '711a'
kConferenceLocation = '711c'
kConferenceDate = '711d'
kMeetingName = kConferenceTitle
kMeetingLocation = kConferenceLocation
kMeetingDate = kConferenceDate

kDescriptionOfBrowseGraphic = '356z1'
kTitleOfBrowseGraphic = '356f'
kFileTypeOfBrowseGraphic = '356z2'

kWestBoundingLongitude = '034d'
kEastBoundingLongitude = '034e'
kSouthBoundingLatitude = '034f'
kNorthBoundingLatitude = '034g'

# for persons:

kName = '801'
kEpersID = '802'
kHomeProviderID = '803'
kEmail = '804'
kPassword = '805'
kHomePage = '806'
kRole = '807'
kOrganization = '808'
kAddress = '809'
kCreditCardType = '810'
kCreditCardExpDate = '811'
kCreditCardNo = '814'
kDialogAccountNo = '812'
kCommpacts = '813'
kHomeColl = '815'
kItemType = '816'
kCommpactID = '817'
kCommpactManagerID = '818'

kReportNumber = '027'  ## technical report number

# Metadata about a document object itself (when created, where its contents
# came from, etc.)

kHoldingsNote = '866'

# Data on reproduction of materials.  Used to store insertion date of item
# into collection (this is stretching the field definition quite a bit)

kReproductionMaterials = '843'


## ----------------------------------------------------


USMarc = {}

USMarc[kISBN] = ('ISBN', 'ISBN')
USMarc[kISSN] = ('ISSN', 'ISSN')

USMarc[kCopyright] = ('Copyright', 'Copyright')
USMarc[kLanguage] = ('Lang', 'Publication Language')
USMarc[kCountry] = ('Country', 'Publication Country')

USMarc[kAbbreviatedPublication] = ('AbbrPub', 'Abbreviated Publication')
USMarc[kPublication] = ('Publication', 'Name of Publication')
USMarc[kPublisher] = ('Publisher', 'Name of Publisher')
USMarc[kIssuingOrganization] = ('Organization', 'Name of Issuing Organization')

USMarc[kEdition] = ('Edition', 'Edition Statement')
USMarc[kVolume] = ('Volume', 'Publicaton Volume')
USMarc[kSeries] = ('Series', 'Series of Which Publication is a Part')
USMarc[kNumber] = ('Number', 'Publicaton Issue or Technical Report Number')
USMarc[kPhysicalDescription] = ('PhyDesc', 'Physical description')
USMarc[kPageNumber] = ('Pagenum', 'Page numbers of article')

USMarc[kSubjectPersonalName] = ('Subject', 'Subject -- Personal Name')
USMarc[kSubjectCorporateName] = ('Subject', 'Subject -- Corporate Name')
USMarc[kSubjectTopicalTerm] = ('Subject', 'Subject -- Topical Term')
USMarc[kSubjectGeographicName] = ('Subject', 'Subject -- Geographic Name')

USMarc[kConferenceTitle] = ('Name', 'Meeting Name')
USMarc[kConferenceLocation] = ('Location', 'Meeting Location')
USMarc[kConferenceDate] = ('Date', 'Meeting Date')

USMarc[kPublicationDate] = ('Date', 'Publication Date')
USMarc[kPublicationYear] = ('Year', 'Publication Year')
USMarc[kTitleStatement] = ('Title', 'Title Statement')
USMarc[kMainEntryPersonalName] = ('Author', 'Main Entry -- PersonalName (primary Author)')
USMarc[kMainEntryUniformTitle] = ('Title', 'Main Entry -- Uniform Title')
USMarc[kUniformTitle] = ('Title', 'Uniform Title')
USMarc[kVaryingTitle] = ('TitleVariation', 'Varying Form of Title')
USMarc[kAbstract] = ('Abstract', 'Summary, abstract, annotation')
USMarc[kGeneralNote] = ('GenNote', 'General Note (like document type)')
USMarc[kBibliographicNote] = ('Note', 'Bibliographic Note')

## Added by AC
USMarc[kMovieURL] = ('Movie URL', 'URL of a Movie')
USMarc[kFilmStripURL] = ('FilmStrip URL', 'URL of a FilmStrip')
USMarc[kTranscriptURL] = ('Transcript URL', 'URL of a Transcript')
## End of addition


USMarc[kContent] = ('Content', 'Content')
USMarc[kContentLength] = ('Length', 'Content-Length')
USMarc[kContentType] = ('ContentType', 'conference paper, technical report, etc.')
USMarc[kContentTypeNote] = ('ContentNote', 'what is included in the content (like an abstract, illustrations, etc.)')

USMarc[kWeight] = ('Weight', 'Weight of this document (in relation to a query.)')
USMarc[kURL] = ('URL', 'Uniform Resource Locator')
USMarc[kOrdering] = ('Order', 'Absolute ordering index')
USMarc[kAdvertisement] = ('Ad', 'Advertisement')


USMarc[kDescriptionOfBrowseGraphic] = ('Browse Graphic Description', 'Description of Browse Graphic')
USMarc[kTitleOfBrowseGraphic] = ('Browse Graphic Title', 'Title of browse graphic')
USMarc[kFileTypeOfBrowseGraphic] = ('Browse Graphic File Type', 'File type (e.g., GIF) of browse graphic:')

USMarc[kWestBoundingLongitude] = ('West-Bounding Longitude', 'West-Bounding Longitude')
USMarc[kEastBoundingLongitude] = ('East-Bounding Longitude', 'East-Bounding Longitude')
USMarc[kNorthBoundingLatitude] = ('North-Bounding Latitude', 'North-Bounding Latitude')
USMarc[kSouthBoundingLatitude] = ('South-Bounding Latitude', 'South-Bounding Latitude')

USMarc[kName] = ('name', 'Person Name')
USMarc[kEpersID] = ('epersID', 'Epers ID')
USMarc[kCommpactID] = ('commpactID', 'Commpact ID')
USMarc[kCommpactManagerID] = ('commpactManagerID', 'Commpact Manager ID')
USMarc[kItemType] = ('itemType', 'Type of Item')
USMarc[kHomeProviderID] = ('homeProviderID', 'Home provider ID')
USMarc[kEmail] = ('eMail', 'e-mail')
USMarc[kPassword] = ('password', 'Password')
USMarc[kHomePage] = ('homePage', 'Web home page')
USMarc[kRole] = ('role', 'Role')
USMarc[kOrganization] = ('organization', 'Organization')
USMarc[kAddress] = ('address', 'Address')
USMarc[kCreditCardType] = ('creditCardType', 'Credit Card Type')
USMarc[kCreditCardNo] = ('creditCardNo', 'Credit Card Number')
USMarc[kCreditCardExpDate] = ('creditCardExpDate', 'Credit Card Exp Date')
USMarc[kDialogAccountNo] = ('dialogAccountNo', 'Dialog Account No')
USMarc[kCommpacts] = ('commpacts', 'Commpacts')
USMarc[kHomeColl] = ('homeColl', 'Home Collector')

USMarc[kHoldingsNote] = ('__Metadata__', 'Metadata about document object')
USMarc[kReproductionMaterials] = ('__TimeStamp__', 'Date of item insertion into collection')

gEnglish2USMarc = {}

gEnglish2USMarc['isbn'] = kISBN
gEnglish2USMarc['issn'] = kISSN
gEnglish2USMarc['date'] = kPublicationDate
gEnglish2USMarc['year'] = kPublicationYear
gEnglish2USMarc['title'] = kTitleStatement
gEnglish2USMarc['titleVariation'] = kVaryingTitle
gEnglish2USMarc['author'] = kMainEntryPersonalName
gEnglish2USMarc['abstract'] = kAbstract 
gEnglish2USMarc['note'] = kGeneralNote  # formerly kBibliographicNote - tes

gEnglish2USMarc['organ'] = kIssuingOrganization

gEnglish2USMarc['subject'] = kSubjectTopicalTerm
gEnglish2USMarc['publication'] = kPublication
gEnglish2USMarc['publisher'] = kPublisher
gEnglish2USMarc['edition'] = kEdition
gEnglish2USMarc['volume'] = kVolume
gEnglish2USMarc['series'] = kSeries
gEnglish2USMarc['number'] = kNumber
gEnglish2USMarc['desc'] = kPhysicalDescription
gEnglish2USMarc['pagenum'] = kPageNumber

gEnglish2USMarc['country'] = kCountry
gEnglish2USMarc['abbrpub'] = kAbbreviatedPublication
gEnglish2USMarc['language'] = kLanguage

gEnglish2USMarc['copyright'] = kCopyright

## Added by AC
gEnglish2USMarc['movie'] = kMovieURL
gEnglish2USMarc['movie url'] = kMovieURL
gEnglish2USMarc['filmstrip'] = kFilmStripURL
gEnglish2USMarc['filmstrip url'] = kFilmStripURL
gEnglish2USMarc['transcript'] = kTranscriptURL
gEnglish2USMarc['transcript url'] = kTranscriptURL
## End of addition

gEnglish2USMarc['content'] = kContent 
gEnglish2USMarc['length'] = kContentLength 
gEnglish2USMarc['contenttype'] = kContentType 
gEnglish2USMarc['typenote'] = kContentTypeNote 
gEnglish2USMarc['weight'] = kWeight 
gEnglish2USMarc['url'] = kURL 
gEnglish2USMarc['order'] = kOrdering
gEnglish2USMarc['ad'] = kAdvertisement

gEnglish2USMarc['bgdescription'] = kDescriptionOfBrowseGraphic 
gEnglish2USMarc['bgtitle'] = kTitleOfBrowseGraphic 
gEnglish2USMarc['bgtype'] = kFileTypeOfBrowseGraphic 

gEnglish2USMarc['west'] = kWestBoundingLongitude
gEnglish2USMarc['east'] = kEastBoundingLongitude
gEnglish2USMarc['north'] = kNorthBoundingLatitude
gEnglish2USMarc['south'] = kSouthBoundingLatitude


gEnglish2USMarc['name'] = kName
gEnglish2USMarc['epersid'] = kEpersID
gEnglish2USMarc['commpactid'] = kCommpactID
gEnglish2USMarc['commpactmanagerid'] = kCommpactManagerID
gEnglish2USMarc['itemtype'] = kItemType
gEnglish2USMarc['homeproviderid'] = kHomeProviderID
gEnglish2USMarc['email'] = kEmail
gEnglish2USMarc['homepage'] = kHomePage
gEnglish2USMarc['role'] = kRole
gEnglish2USMarc['organization'] = kOrganization
gEnglish2USMarc['address'] = kAddress
gEnglish2USMarc['creditcardtype'] = kCreditCardType
gEnglish2USMarc['creditcardexpdate'] = kCreditCardExpDate
gEnglish2USMarc['creditcardno'] = kCreditCardNo
gEnglish2USMarc['dialogaccountno'] = kDialogAccountNo
gEnglish2USMarc['commpacts'] = kCommpacts
gEnglish2USMarc['homecoll'] = kHomeColl

gEnglish2USMarc['__Metadata__'] = kHoldingsNote
gEnglish2USMarc['__TimeStamp__'] = kReproductionMaterials

import bibconvert
gUSMarcAttributeConverter = bibconvert.AttributeConverter(USMarc)

def USMarc2English(pField): return gUSMarcAttributeConverter.convertAttr(pField)[0]
def USMarc2LongEnglish(pField): return gUSMarcAttributeConverter.convertAttr(pField)[1]


English2USMarcAttributeConverter = bibconvert.AttributeConverter(gEnglish2USMarc)

def English2USMarc(pField): return English2USMarcAttributeConverter.convertAttr(pField)



